Struct melpomene::sim_drivers::emb_display::CommanderTask
source · struct CommanderTask {
kernel: &'static Kernel,
cmd: RequestStream<EmbDisplayService>,
width: u32,
height: u32,
}Expand description
This task is spawned by the call to SimDisplay::register. It is a single
async function that will process requests, and periodically redraw the
framebuffer.
Fields
kernel: &'static Kernelcmd: RequestStream<EmbDisplayService>width: u32height: u32Implementations
sourceimpl CommanderTask
impl CommanderTask
sourceasync fn run(self, width: u32, height: u32, settings: DisplayConfig)
async fn run(self, width: u32, height: u32, settings: DisplayConfig)
The entrypoint for the driver execution